@@ -38,7 +38,7 @@ impl ItemsSpec {
                         })
                     }
                 };
-                spec.column_index_to_value(dataset)?;
+                spec.preprocess_columns(dataset)?;
             }
         }
         Ok(items_spec)
@@ -94,30 +94,36 @@ pub(crate) struct ItemSpecs {
 }
 
 lazy_static! {
-    static ref INDEX: Regex = Regex::new(r"index\(([0-9]+)\)").unwrap();
+    static ref INDEX_RE: Regex = Regex::new(r"^index\(([0-9]+)\)$").unwrap();
+}
+
+lazy_static! {
+    static ref REGEX_RE: Regex = Regex::new(r"^regex\('(.+)'\)$").unwrap();
 }
 
 impl ItemSpecs {
-    /// Converts columns addressed with index to the actual header values of the table
-    fn column_index_to_value(&mut self, dataset: &DatasetSpecs) -> Result<()> {
+    /// Preprocesses columns with index and regex notation
+    fn preprocess_columns(&mut self, dataset: &DatasetSpecs) -> Result<()> {
         let mut indexed_keys = HashMap::new();
         let mut reader = csv::ReaderBuilder::new()
             .delimiter(dataset.separator as u8)
             .from_path(&dataset.path)
             .context(format!("Could not read file with path {:?}", &dataset.path))?;
         let headers = reader.headers()?;
+
         for (key, render_column_specs) in self.render_table.as_ref().unwrap().iter() {
-            if INDEX.is_match(key) {
-                let index = usize::from_str(
-                    INDEX
-                        .captures_iter(key)
-                        .collect_vec()
-                        .pop()
-                        .unwrap()
-                        .get(1)
-                        .unwrap()
-                        .as_str(),
-                )?;
+            let get_first_match_group = |regex: &Regex| {
+                regex
+                    .captures_iter(key)
+                    .collect_vec()
+                    .pop()
+                    .unwrap()
+                    .get(1)
+                    .unwrap()
+                    .as_str()
+            };
+            if INDEX_RE.is_match(key) {
+                let index = usize::from_str(get_first_match_group(&INDEX_RE))?;
                 match headers.get(index) {
                     None => {
                         bail!(ConfigError::IndexTooLarge {
@@ -138,6 +144,23 @@ impl ItemSpecs {
                         };
                     }
                 }
+            } else if REGEX_RE.is_match(key) {
+                let pattern = get_first_match_group(&REGEX_RE);
+                let regex = Regex::new(pattern).context(format!(
+                    "Failed to parse provided column regex {key}.",
+                    key = key
+                ))?;
+                for header in headers.iter().filter(|header| regex.is_match(header)) {
+                    if indexed_keys
+                        .insert(header.to_string(), render_column_specs.clone())
+                        .is_some()
+                    {
+                        bail!(ConfigError::DuplicateColumn {
+                            column: header.to_string(),
+                            table_path: dataset.path.clone()
+                        })
+                    }
+                }
             } else if indexed_keys
                 .insert(key.to_string(), render_column_specs.clone())
                 .is_some()
@@ -401,4 +424,40 @@ mod tests {
         let config: ItemsSpec = serde_yaml::from_str(raw_config).unwrap();
         assert_eq!(config, expected_config);
     }
+
+    #[test]
+    fn test_config_preprocessing() {
+        let config = ItemsSpec::from_file(".examples/example-config.yaml").unwrap();
+        let oscar_config = config
+            .views
+            .get("oscars")
+            .unwrap()
+            .render_table
+            .as_ref()
+            .unwrap();
+        let expected_render_column_spec = RenderColumnSpec {
+            optional: false,
+            custom: None,
+            display_mode: "detail".to_string(),
+            link_to_url: None,
+            plot: None,
+            custom_plot: None,
+        };
+        assert_eq!(
+            oscar_config.get("oscar_no").unwrap().to_owned(),
+            expected_render_column_spec
+        );
+        assert_eq!(
+            oscar_config.get("birth_mo").unwrap().to_owned(),
+            expected_render_column_spec
+        );
+        assert_eq!(
+            oscar_config.get("birth_d").unwrap().to_owned(),
+            expected_render_column_spec
+        );
+        assert_eq!(
+            oscar_config.get("birth_y").unwrap().to_owned(),
+            expected_render_column_spec
+        );
+    }
 }
